@@ -16,16 +16,14 @@ spec = do
         it "produces valid sets" $
         genGeneratesValid
             (genStructurallyValidSetOf @Rational genValid)
-            (const [])
     describe "genStructurallyValidSetOfInvalidValues" $
         it "produces valid sets" $
         genGeneratesInvalid
             (genStructurallyValidSetOfInvalidValues @Rational)
-            (const [])
 #if MIN_VERSION_containers(0,5,9)
     describe "genStructurallyInvalidSet" $
         it "produces invalid sets" $
-        genGeneratesInvalid (genStructurallyInvalidSet @Rational) (const [])
+        genGeneratesInvalid (genStructurallyInvalidSet @Rational)
 #endif
     genValidSpec @(Set Int)
     genValiditySpec @(Set Rational)
